==> 0.7.0.tar.gz: bin/acdart_heroku_setup.dart <==
#!/usr/bin/env dart

import 'dart:io';
import 'dart:async';
import 'package:uuid/uuid.dart';
import 'package:atlassian_connect_config/atlassian_connect_config.dart';
import 'package:unscripted/unscripted.dart' as cmd;

const MONGOHQ_URL_CONFIG_NAME = 'MONGOHQ_URL';

main(arguments) => cmd.declare(setupHeroku).execute(arguments);

@cmd.Command(help: 'Set up Heroku for AcDart addon', 
    plugins: const [const cmd.Completion()])
@cmd.ArgExample('myApp', 
    help: 'create an AcDart addon called myApp')
setupHeroku(
  @cmd.Positional(help: 'Addon name')
  String appName) {
  final heroku = new HerokuClient(appName);
  return heroku.createApp().then((_) =>
    heroku.addAddon('mongohq')).then((_) =>
    heroku.getConfig(MONGOHQ_URL_CONFIG_NAME)).then((mongoUrl) {
      final herokuConfig = {
        AcDartEnvironment.AC_ENV: EnvironmentNames.production,
        AcDartEnvironment.AC_ADDON_SECRET: new Uuid().v4(),
        AcDartEnvironment.AC_BASE_URL: 'https://$appName.herokuapp.com/',
        AcDartEnvironment.AC_MONGO_HOST_URL: mongoUrl,
        'BUILDPACK_URL': 'https://github.com/igrigorik/heroku-buildpack-dart.git',
        'DART_SDK_URL': 'https://www.dropbox.com/s/hxh64kesz2xw6sy/dart-sdk.tar'
      };
      return heroku.setConfig(herokuConfig);
    });
}

class HerokuClient {
  final String appName;
  HerokuClient(this.appName);
  
  Future createApp() => runHeroku(['create', appName]);
    
  Future<Map<String, String>> getAllConfig() {
    return runCurrentApp(['config']).then((String stdout) {
      final config = <String, String>{};
      stdout.split('\n').skip(1) // first line is header
          .forEach((line) {
        if (line != null && line.trim() != '') {
          final kv = line.split(new RegExp(r':[\s]+'));
          if (kv.length != 2) {
            throw new StateError('invalid config line $line');
          }
          config[kv[0]] = kv[1];
        }
      });
      return config;
    });
  }
  
  Future<String> getConfig(String variableName) =>
      runCurrentApp(['config:get', variableName]);
  
  Future setConfig(Map<String, String> config) {
    final args = ['config:set']..addAll(config.keys.map((k) => '$k=${config[k]}'));
    return runCurrentApp(args);
  }
    
  Future addAddon(String addonName) =>
      runCurrentApp(['addons:add', addonName]);
  
  
  Future<String> runHeroku(List<String> args) {
    print('running heroku $args');
    return Process.run("heroku", args).then((processResult) {
      if (processResult.exitCode != 0) {
        throw new ArgumentError("failed to execute command $args\n${processResult.stderr}");
      }
      return processResult.stdout;
    });
  }
  
  Future<String> runCurrentApp(List<String> args) {
    final fullArgs = []..addAll(args)..addAll(['--app', appName]);
    return runHeroku(fullArgs);
  }
//  Process.runSync("executable", []);
}

==> 0.10.0.tar.gz: bin/acdart_heroku_setup.dart <==
#!/usr/bin/env dart

import 'dart:io';
import 'dart:async';
import 'package:uuid/uuid.dart';
import 'package:atlassian_connect_config/atlassian_connect_config.dart';
import 'package:unscripted/unscripted.dart' as cmd;

const MONGOHQ_URL_CONFIG_NAME = 'MONGOHQ_URL';

main(arguments) => cmd.declare(setupHeroku).execute(arguments);

@cmd.Command(help: 'Set up Heroku for AcDart addon', 
    plugins: const [const cmd.Completion()])
@cmd.ArgExample('myApp', 
    help: 'create an AcDart addon called myApp')
setupHeroku(
  @cmd.Positional(help: 'Addon name')
  String appName) {
  final heroku = new HerokuClient(appName);
  return heroku.createApp().then((_) =>
    heroku.addAddon('mongohq')).then((_) =>
    heroku.getConfig(MONGOHQ_URL_CONFIG_NAME)).then((mongoUrl) {
      final herokuConfig = {
        AcDartEnvironment.AC_ENV: EnvironmentNames.production,
        AcDartEnvironment.AC_ADDON_SECRET: new Uuid().v4(),
        AcDartEnvironment.AC_BASE_URL: 'https://$appName.herokuapp.com',
        AcDartEnvironment.AC_MONGO_HOST_URL: mongoUrl,
        'BUILDPACK_URL': 'https://github.com/igrigorik/heroku-buildpack-dart.git',
        'DART_SDK_URL': 'https://www.dropbox.com/s/hxh64kesz2xw6sy/dart-sdk.tar'
      };
      return heroku.setConfig(herokuConfig);
    });
}

class HerokuClient {
  final String appName;
  HerokuClient(this.appName);
  
  Future createApp() => runHeroku(['create', appName]);
    
  Future<Map<String, String>> getAllConfig() {
    return runCurrentApp(['config']).then((String stdout) {
      final config = <String, String>{};
      stdout.split('\n').skip(1) // first line is header
          .forEach((line) {
        if (line != null && line.trim() != '') {
          final kv = line.split(new RegExp(r':[\s]+'));
          if (kv.length != 2) {
            throw new StateError('invalid config line $line');
          }
          config[kv[0]] = kv[1];
        }
      });
      return config;
    });
  }
  
  Future<String> getConfig(String variableName) =>
      runCurrentApp(['config:get', variableName]);
  
  Future setConfig(Map<String, String> config) {
    final args = ['config:set']..addAll(config.keys.map((k) => '$k=${config[k]}'));
    return runCurrentApp(args);
  }
    
  Future addAddon(String addonName) =>
      runCurrentApp(['addons:add', addonName]);
  
  
  Future<String> runHeroku(List<String> args) {
    print('running heroku $args');
    return Process.run("heroku", args).then((processResult) {
      if (processResult.exitCode != 0) {
        throw new ArgumentError("failed to execute command $args\n${processResult.stderr}");
      }
      return processResult.stdout;
    });
  }
  
  Future<String> runCurrentApp(List<String> args) {
    final fullArgs = []..addAll(args)..addAll(['--app', appName]);
    return runHeroku(fullArgs);
  }
//  Process.runSync("executable", []);
}
